This folder contains configurations / credentials for using various cloud providers.
These configurations / credentials should not be tied to any actual account, and should contain sample information unless validation by the client is required.
